@@ -73,15 +73,15 @@ class PseudocodefrLexer(RegexLexer):
                   r'booleens?|tableaux?|rien)\s*\b', 
                   Keyword.Type),
 
-                  (r'\b(vrai|faux|nil)\s*\b',
+                  (r'\b(pi|nil)\s*\b',
                    Name.Constant),
-                  
+                  (r'\b(vrai|faux|nil)\s*\b',
+                   Name.Bin),
+
                  # Operators
                  (r'(<=|>=|<>|!=|<-|\^|\*|\+|-|\/|<|>|=|\\\\|mod|←|↑|→|≤|≥|≠|÷|×|\.\.|\[|\]|\.|non|xou|et|ou)',
                   op_replace),
 
-
-
                  (r'(\(|\)|\,|\;|:)',
                   Punctuation),
 
